==> babelator-0.2.3.tgz: package/src/tasks/babel-modules.js <==
//region Imports
const path = require('path')
const _ = require('lodash')
//endregion

// Babel logging.
function logFileHelpers() {
  const through = require('through2')
  const gutil = require('gulp-util')

  return through.obj(function(file, enc, cb) {
    var src = file.history[0]
    var dest = file.history[1]
    // TODO(vjpr): When generating source maps this should print src as generated.
    const relPath = (f) => { return path.relative('.', f) }
    gutil.log('Compiling (Babel):', gutil.colors.red(relPath(src) + ' -> ' + relPath(dest)))
    //gutil.log(file.babel.usedHelpers)
    cb(null, file)
  })
}

function onError() {
  const notify = require('gulp-notify')
  return notify.onError('<%= error.message %>')
}

export default (gulp, opts = {}) => {

  ////////
  // This is shared.
  const transformAsyncToModuleMethod = require('babel-plugin-transform-async-to-module-method')
  const asyncPlugin =
    [transformAsyncToModuleMethod, {
      module: 'bluebird',
      method: 'coroutine',
    }]
  const addModuleExports = require('babel-plugin-add-module-exports')
  const transformRuntime = require('babel-plugin-transform-runtime')
  const externalHelpers = require('babel-plugin-external-helpers-2')
  const transformDecoratorsLegacy = require('babel-plugin-transform-decorators-legacy')
  const babelDefaults = {
    plugins: [externalHelpers, asyncPlugin, transformRuntime, addModuleExports, transformDecoratorsLegacy],
    presets: ['es2015', 'stage-0', 'react']
  }
  ////////

  const srcDir = process.cwd() + '/modules'
  const destDir = 'lib-modules'

  // TODO(vjpr): This is very bad! We should make each task generic. Should export just functions.
  // Or this might be fine.
  opts = _.merge({}, opts, {
    srcGlob: srcDir + '/**/*.js',
    srcFilesGlob: srcDir + '/**/!(*.js|*.jsx)',
    destGlob: destDir + '/**/*',
    testsGlob: srcDir + '/**/__tests__/**/*-test.js',
    shouldCompileTests: false,
    babel: babelDefaults,
    srcDir,
    destDir,
    sourceMaps: false,
  })

  gulp.task('lib-modules:compile', gulp.series(['lib-modules:compile-js', 'lib-modules:copy-files']))

  gulp.task('lib-modules:compile-js', () => {
    const gulpif = require('gulp-if')
    const changed = require('gulp-changed')
    const ignore = require('gulp-ignore')
    const babel = require('gulp-babel')
    const sourcemaps = require('gulp-sourcemaps')
    const cwd = require('cwd')

    return gulp.src(opts.srcGlob)
      .pipe(gulpif(gulp.isWatching, changed(opts.destDir)))
      .pipe(gulpif(!opts.shouldCompileTests, ignore.exclude(opts.testsGlob)))
      .pipe(gulpif(opts.sourceMaps, sourcemaps.init()))
      .pipe(babel(opts.babel))
      .on('error', onError())
      // Source maps work with IntelliJ debugger using Node.js 0.12.7.
      .pipe(gulpif(opts.sourceMaps, sourcemaps.write('.', {
        includeContent: false,
        sourceRoot: file => {
          return path.join(path.relative(file.path, cwd()), opts.srcDir)
        }
      })))
      .pipe(gulp.dest(opts.destDir))
      .pipe(logFileHelpers())
  })

  gulp.task('lib-modules:copy-files', () => {
    return gulp.src(opts.srcFilesGlob).pipe(gulp.dest(opts.destDir))
  })

  gulp.task('lib-modules:clean', () => {
    const del = require('del')
    const gutil = require('gulp-util')

    gutil.log('Cleaning:', gutil.colors.red(opts.destDir))
    return del(opts.destGlob)
  })

  gulp.task('lib-modules:watch', gulp.series('lib-modules:clean', 'lib-modules:compile', function watcher() {
    const gutil = require('gulp-util')

    // Used by `compile` task to check whether we should only compile changed files.
    gulp.isWatching = true

    gulp.watch(opts.srcGlob, gulp.series('lib-modules:compile')).on('change', (evt) => {
      gutil.log('---')
      gutil.log('File changed:', gutil.colors.red(evt))
    })

  }))

}

==> babelator-0.2.7.tgz: package/src/tasks/babel-modules.js <==
//region Imports
const path = require('path')
const _ = require('lodash')
const cwd = require('cwd')
//endregion

function getOpts(opts) {

  const srcDir = cwd('/modules')
  const destDir = 'lib-modules'

  // TODO(vjpr): This is very bad! We should make each task generic. Should export just functions.
  // Or this might be fine.
  opts = _.merge({}, opts, {
    srcGlob: srcDir + '/**/*.js',
    srcFilesGlob: srcDir + '/**/!(*.js|*.jsx)',
    destGlob: destDir + '/**/*',
    testsGlob: srcDir + '/**/__tests__/**/*-test.js',
    shouldCompileTests: false,
    babel: {}, // See src/config.
    srcDir,
    destDir,
    sourceMaps: false,
  })

  return opts

}

export default (gulp, opts = {}) => {

  opts = getOpts(opts)

  gulp.task('lib-modules:compile', gulp.series(['lib-modules:compile-js', 'lib-modules:copy-files']))

  gulp.task('lib-modules:compile-js', () => {
    const gulpif = require('gulp-if')
    const changed = require('gulp-changed')
    const ignore = require('gulp-ignore')
    const babel = require('gulp-babel')
    const sourcemaps = require('gulp-sourcemaps')
    const cwd = require('cwd')

    return gulp.src(opts.srcGlob)
      .pipe(gulpif(gulp.isWatching, changed(opts.destDir)))
      .pipe(gulpif(!opts.shouldCompileTests, ignore.exclude(opts.testsGlob)))
      .pipe(gulpif(opts.sourceMaps, sourcemaps.init()))
      .pipe(babel(opts.babel))
      .on('error', onError())
      // Source maps work with IntelliJ debugger using Node.js 0.12.7.
      .pipe(gulpif(opts.sourceMaps, sourcemaps.write('.', {
        includeContent: false,
        sourceRoot: file => {
          return path.join(path.relative(file.path, cwd()), opts.srcDir)
        }
      })))
      .pipe(gulp.dest(opts.destDir))
      .pipe(logFileHelpers())
  })

  gulp.task('lib-modules:copy-files', () => {
    return gulp.src(opts.srcFilesGlob).pipe(gulp.dest(opts.destDir))
  })

  gulp.task('lib-modules:clean', () => {
    const del = require('del')
    const gutil = require('gulp-util')

    gutil.log('Cleaning:', gutil.colors.red(opts.destDir))
    return del(opts.destGlob)
  })

  gulp.task('lib-modules:watch', gulp.series('lib-modules:clean', 'lib-modules:compile', function watcher() {
    const gutil = require('gulp-util')

    // Used by `compile` task to check whether we should only compile changed files.
    gulp.isWatching = true

    gulp.watch(opts.srcGlob, gulp.series('lib-modules:compile')).on('change', (evt) => {
      gutil.log('---')
      gutil.log('File changed:', gutil.colors.red(evt))
    })

  }))

}

// Babel logging.
function logFileHelpers() {
  const through = require('through2')
  const gutil = require('gulp-util')

  return through.obj(function(file, enc, cb) {
    var src = file.history[0]
    var dest = file.history[1]
    // TODO(vjpr): When generating source maps this should print src as generated.
    const relPath = (f) => { return path.relative('.', f) }
    gutil.log('Compiling (Babel):', gutil.colors.red(relPath(src) + ' -> ' + relPath(dest)))
    //gutil.log(file.babel.usedHelpers)
    cb(null, file)
  })
}

function onError() {
  const notify = require('gulp-notify')
  return notify.onError('<%= error.message %>')
}
